unit fSetup;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ComCtrls, ExtCtrls, cVisualComponents;

type
  TfrmSetup = class(TForm)
    pcSetup: TPageControl;
    tsGeneral: TTabSheet;
    tsNetwork: TTabSheet;
    bOK: TButton;
    bCancel: TButton;
    gPublishedDirectory: TGroupBox;
    bPubDirBrowse: TButton;
    ePubDir: TEdit;
    Image3: TImage;
    gSettings: TGroupBox;
    cAutoRun: TCheckBox;
    Image1: TImage;
    gServer: TGroupBox;
    Image2: TImage;
    Label1: TLabel;
    ePort: TComboBox;
    gBandwidth: TGroupBox;
    Image4: TImage;
    cLimitBandwidth: TCheckBox;
    eBandwidthLimit: TEdit;
    lBandwidthLimit: TLabel;
    Image5: TImage;
    Image6: TImage;
    Image7: TImage;
    dPubDir: TfndDirectoryDialog;
    tsLog: TTabSheet;
    GroupBox1: TGroupBox;
    Image9: TImage;
    lLogFormat: TLabel;
    eLogFormat: TEdit;
    cLogToFile: TCheckBox;
    lLog1: TLabel;
    lLog2: TLabel;
    lLog3: TLabel;
    lLog4: TLabel;
    lLog5: TLabel;
    lLog6: TLabel;
    lLog7: TLabel;
    lLog8: TLabel;
    lLog9: TLabel;
    cExecEXEasCGI: TCheckBox;
    procedure FormCreate(Sender: TObject);
    procedure cLimitBandwidthClick(Sender: TObject);
    procedure cLogToFileClick(Sender: TObject);
    procedure bPubDirBrowseClick(Sender: TObject);
    procedure eBandwidthLimitKeyPress(Sender: TObject; var Key: Char);
    procedure ePortKeyPress(Sender: TObject; var Key: Char);
  private
    AutoRun : Boolean;

    procedure CheckControls;
    procedure Apply;
  public
  end;

function ShowSetupForm: Boolean;

implementation

uses
  cWindows,
  cControls,
  fMain;

{$R *.dfm}

function ShowSetupForm: Boolean;
var frmSetup: TfrmSetup;
begin
  frmSetup := TfrmSetup.Create(nil);
  try
    Result := frmSetup.ShowModal = mrOk;
    if Result then
      frmSetup.Apply;
  finally
    frmSetup.Free;
  end;
end;

procedure TfrmSetup.FormCreate(Sender: TObject);
begin
  pcSetup.ActivePage := tsGeneral;
  AutoRun := IsApplicationAutoRun('EternalLines WebServer');
  cAutoRun.Checked := AutoRun;
  With frmMain.Settings do
    begin
      ePubDir.Text := PubDir;
      ePort.Text := IntToStr(Port);
      cLimitBandwidth.Checked := Throttle and (ThrottleRate > 0);
      if ThrottleRate = 0 then
        eBandwidthLimit.Text := '' else
        eBandwidthLimit.Text := IntToStr(ThrottleRate);
      cLogToFile.Checked := LogToFile;
      eLogFormat.Text := LogFormat;
      cExecEXEasCGI.Checked := ExecEXEasCGI;
    end;
  CheckControls;
end;

procedure TfrmSetup.Apply;
begin
  if AutoRun <> cAutoRun.Checked then
    begin
      AutoRun := cAutoRun.Checked;
      SetApplicationAutoRun('EternalLines WebServer', AutoRun);
    end;
  With frmMain.Settings do
    begin
      PubDir := ePubDir.Text;
      Port := StrToIntDef(ePort.Text, 80);
      ThrottleRate := StrToIntDef(eBandwidthLimit.Text, 0);
      Throttle := cLimitBandwidth.Checked and (ThrottleRate > 0);
      LogToFile := cLogToFile.Checked;
      LogFormat := eLogFormat.Text;
      ExecEXEasCGI := cExecEXEasCGI.Checked;
    end;
end;

procedure TfrmSetup.CheckControls;
var R: Boolean;
begin
  R := cLimitBandwidth.Checked;
  SetCtrlEnabled(eBandwidthLimit, R);
  SetCtrlEnabled(lBandwidthLimit, R);
  R := cLogToFile.Checked;
  SetCtrlEnabled(eLogFormat, R);
  SetCtrlEnabled(lLogFormat, R);
  SetCtrlEnabled(lLog1, R);
  SetCtrlEnabled(lLog2, R);
  SetCtrlEnabled(lLog3, R);
  SetCtrlEnabled(lLog4, R);
  SetCtrlEnabled(lLog5, R);
  SetCtrlEnabled(lLog6, R);
  SetCtrlEnabled(lLog7, R);
  SetCtrlEnabled(lLog8, R);
  SetCtrlEnabled(lLog9, R);
end;

procedure TfrmSetup.cLimitBandwidthClick(Sender: TObject);
begin
  CheckControls;
end;

procedure TfrmSetup.cLogToFileClick(Sender: TObject);
begin
  CheckControls;
end;

procedure TfrmSetup.bPubDirBrowseClick(Sender: TObject);
begin
  if dPubDir.Execute then
    ePubDir.Text := dPubDir.DirPath;
end;

procedure TfrmSetup.eBandwidthLimitKeyPress(Sender: TObject;
  var Key: Char);
begin
  if not (Key in [#8, #13, '0'..'9']) then
    Key := #0;
end;

procedure TfrmSetup.ePortKeyPress(Sender: TObject; var Key: Char);
begin
  if not (Key in [#8, #13, '0'..'9']) then
    Key := #0;
end;

end.
